@@ -1,5 +1,5 @@
 import qdarktheme
-from PySide6.QtCore import QSettings
+from PySide6.QtCore import QSettings, Slot
 from PySide6.QtGui import QIcon, QPainter, QPixmap
 from PySide6.QtWidgets import QApplication, QColorDialog, QDialog
 
@@ -31,10 +31,17 @@ class AppSettings:
             self.currentAccent = self.DEFAULTS.get(self.currentTheme)
 
     def updateTheme(self):
-        self.app.setStyleSheet(qdarktheme.load_stylesheet(
-            self.currentTheme, custom_colors={"primary": self.currentAccent}))
+        qdarktheme.setup_theme(self.currentTheme, custom_colors={
+                               "primary": self.currentAccent})
         self.app.setPalette(qdarktheme.load_palette(self.currentTheme))
 
+    @Slot()
+    def resetToDefaults(self):
+        self.currentTheme = "dark"
+        self.currentAccent = self.DEFAULTS.get("dark")
+        self.updateTheme()
+
+    @Slot()
     def openSettings(self):
         window = SettingsWindow(self, self.icon)
 
@@ -74,12 +81,18 @@ class SettingsWindow(QDialog, Ui_SettingsWindow):
         self.setupUi(self)
         self.btnApply.setDefault(True)
 
-        if icon is not None and isinstance(icon, (QIcon, QPixmap)):
-            self.setWindowIcon(icon)
+        if icon is not None:
+            if isinstance(icon, (QIcon, QPixmap)):
+                self.setWindowIcon(icon)
+            else:
+                raise TypeError(
+                    f"icon cannot be of type '{icon.__class__.__name__}', must be of type QIcon or QPixmap")
 
         self.updatePreview(master.currentAccent)
         self.newAccent = None
-        self.comboxTheme.addItems(["Dark", "Light"])
+        # self.comboxTheme.addItems(["Dark", "Light"])
+        self.comboxTheme.addItems(theme.title()
+                                  for theme in qdarktheme.get_themes())
         self.comboxTheme.setCurrentText(self.master.currentTheme.title())
 
         self.btnChangeAccent.clicked.connect(self.changeAccent)
@@ -110,6 +123,7 @@ class SettingsWindow(QDialog, Ui_SettingsWindow):
 
         self.lblColourPreview.setPixmap(preview)
 
+    @Slot()
     def changeAccent(self):
         dialog = QColorDialog(self.master.currentAccent, self)
         dialog.setWindowTitle("Choose Accent Colour")
